@@ -33,7 +33,9 @@ class Target(NamedTuple):
         )
 
 
-def get_targets(debug: bool, paths: Paths, fail_on_missing: bool) -> List[Target]:
+def get_targets(
+    debug: bool, paths: Paths, fail_on_missing: bool, whitelist: List[str],
+) -> List[Target]:
     targets = paths.targets_debug if debug else paths.targets
     if not targets.exists():
         if fail_on_missing:
@@ -42,4 +44,8 @@ def get_targets(debug: bool, paths: Paths, fail_on_missing: bool) -> List[Target
         else:
             return []
     with targets.open("r", encoding="utf8") as fh:
-        return [Target.from_dict(target) for target in yaml_safe_load(fh)]
+        return [
+            Target.from_dict(target)
+            for target in yaml_safe_load(fh)
+            if not whitelist or target["name"] in whitelist
+        ]
